@@ -62,15 +62,15 @@
 		    (null? (car x))
 		    (= i (*s7* 'history-size)))
 		(format p "~%error-history:~%    ~S" (car start))
-		(do ((x history (cdr x))
+		(do ((expr history (cdr expr))
 		     (line lines (cdr line))
 		     (f files (cdr f)))
-		    ((null? x))
-		  (format p (if (and (integer? (car line))
-				     (string? (car f))
-				     (not (string=? (car f) "*stdout*")))
-				(values "~%    ~S~40T;~A[~A]" (car x) (car f) (car line))
-				(values "~%    ~S" (car x)))))
+		    ((null? expr))
+		  (if (and (integer? (car line))
+			   (string? (car f))
+			   (not (string=? (car f) "*stdout*")))
+		      (format p "~%    ~S~40T;~A[~A]" (car expr) (car f) (car line))
+		      (format p "~%    ~S" (car expr))))
 		(format p "~%"))
 	     (set! history (cons (car x) history))
 	     (set! lines (cons (and (pair? (car x)) (pair-line-number (car x))) lines))
@@ -82,8 +82,10 @@
 	 (do ((e (outlet ow) (outlet e))) 
 	     ((memq e elist)
 	      (set! (*s7* 'print-length) old-print-length))
-	   (if (> (length e) 0)
-	       (format p "~%~{~A~| ~}~%" e))
+	   (if (and (number? (length e)) ; with-let + mock-data + length method?
+		    (> (length e) 0))
+	       (format p "~%~{~A~| ~}~%" e)
+	       (format p "e: ~S~%" e))
 	   (set! elist (cons e elist))))))))
 
 #|
@@ -1442,7 +1444,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :initial-string-port-length    (*s7* 'initial-string-port-length)
    :default-rationalize-error     (*s7* 'default-rationalize-error)
    :default-random-state          (*s7* 'default-random-state)
-   :equivalent-float-epsilon   (*s7* 'equivalent-float-epsilon)
+   :equivalent-float-epsilon      (*s7* 'equivalent-float-epsilon)
    :hash-table-float-epsilon      (*s7* 'hash-table-float-epsilon)
    :float-format-precision        (*s7* 'float-format-precision)
    :bignum-precision              (*s7* 'bignum-precision)
@@ -1456,6 +1458,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :autoloading?                  (*s7* 'autoloading?)
    :undefined-identifier-warnings (*s7* 'undefined-identifier-warnings)
    :undefined-constant-warnings   (*s7* 'undefined-constant-warnings)
+   :accept-all-keyword-arguments  (*s7* 'accept-all-keyword-arguments)
    :catches                       (*s7* 'catches)
    :history-size                  (*s7* 'history-size)
    :history-enabled               (*s7* 'history-enabled)
